YARP 2.3.2 (2010-11-29)                                                {#v2_3_2}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.1...v2.3.2`):

```
    28	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    17	Ugo Pattacini <ugo.pattacini@iit.it>
     8	Lorenzo Natale <lorenzo.natale@iit.it>
     7	Marco Randazzo <marco.randazzo@iit.it>
     1	Alessandro Scalzo <alessandro.scalzo@iit.it>
     1	Arjan Gijsberts <arjan.gijsberts@idiap.ch>
     1	Daniel Krieg <krieg@fias.uni-frankfurt.de>
     1	Serena Ivaldi <arwen.h@gmail.com>
```
